@@ -4,8 +4,13 @@ import (
 	"bufio"
 	"flag"
 	"fmt"
+	"github.com/openshift/cluster-logging-operator/internal/constants"
 	"io/ioutil"
+	corev1 "k8s.io/api/core/v1"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"os"
+	"sigs.k8s.io/controller-runtime/pkg/client"
+	"sigs.k8s.io/controller-runtime/pkg/client/fake"
 	"strconv"
 
 	"github.com/openshift/cluster-logging-operator/internal/pkg/generator/forwarder"
@@ -65,10 +70,51 @@ func main() {
 
 	log.Info("Finished reading yaml", "content", string(content))
 
-	generatedConfig, err := forwarder.Generate(string(content), *includeDefaultLogStore, *debugOutput, nil)
+	clfYaml := string(content)
+	client := buildClient(clfYaml)
+	generatedConfig, err := forwarder.Generate(clfYaml, *includeDefaultLogStore, *debugOutput, client)
 	if err != nil {
 		log.Error(err, "Unable to generate log configuration")
 		os.Exit(1)
 	}
 	fmt.Println(generatedConfig)
 }
+
+func buildClient(clfYaml string) client.Client {
+
+	instance, err := forwarder.UnMarshalClusterLogForwarder(clfYaml)
+	if err != nil {
+		log.Error(err, "Unable to generate log configuration")
+		os.Exit(1)
+	}
+
+	secrets := []client.Object{}
+	for _, output := range instance.Spec.Outputs {
+		if output.Secret != nil {
+			s := &corev1.Secret{
+				ObjectMeta: metav1.ObjectMeta{
+					Namespace: constants.OpenshiftNS,
+					Name:      output.Secret.Name,
+				},
+				Data: map[string][]byte{
+					constants.ClientPrivateKey:   []byte("value"),
+					constants.ClientCertKey:      []byte("value"),
+					constants.TrustedCABundleKey: []byte("value"),
+				},
+			}
+			secrets = append(secrets, s)
+		}
+	}
+	secrets = append(secrets, &corev1.Secret{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      constants.CollectorSecretName,
+			Namespace: constants.OpenshiftNS,
+		},
+		Data: map[string][]byte{
+			constants.ClientPrivateKey:   []byte("value"),
+			constants.ClientCertKey:      []byte("value"),
+			constants.TrustedCABundleKey: []byte("value"),
+		},
+	})
+	return fake.NewClientBuilder().WithObjects(secrets...).Build()
+}
