@@ -3,9 +3,10 @@ package fluentd
 import (
 	"encoding/json"
 	"fmt"
-	"github.com/openshift/cluster-logging-operator/internal/generator"
 	"strings"
 
+	"github.com/openshift/cluster-logging-operator/internal/generator"
+
 	"github.com/google/go-cmp/cmp"
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/ginkgo/extensions/table"
@@ -146,8 +147,8 @@ var _ = Describe("Testing Complete Config Generation", func() {
 <source>
   @type tail
   @id container-input
-  path "/var/log/containers/*.log"
-  exclude_path ["/var/log/containers/collector-*_openshift-logging_*.log", "/var/log/containers/elasticsearch-*_openshift-logging_*.log", "/var/log/containers/kibana-*_openshift-logging_*.log"]
+  path "/var/log/pods/**/*.log"
+  exclude_path ["/var/log/pods/openshift-logging_collector-*/*/*.log", "/var/log/pods/openshift-logging_elasticsearch-*/*/*.log", "/var/log/pods/openshift-logging_kibana-*/*/*.log"]
   pos_file "/var/lib/fluentd/pos/es-containers.log.pos"
   refresh_interval 5
   rotate_wait 5
@@ -405,6 +406,7 @@ var _ = Describe("Testing Complete Config Generation", func() {
   
   # Invoke kubernetes apiserver to get kunbernetes metadata
   <filter kubernetes.**>
+    @id kubernetes-metadata
     @type kubernetes_metadata
     kubernetes_url 'https://kubernetes.default.svc'
     cache_size '1000'
@@ -421,14 +423,14 @@ var _ = Describe("Testing Complete Config Generation", func() {
     json_fields 'log,MESSAGE'
   </filter>
   
-  <filter kubernetes.var.log.containers.**>
+  <filter kubernetes.var.log.pods.**>
     @type parse_json_field
     merge_json_log 'false'
     preserve_json_log 'true'
     json_fields 'log,MESSAGE'
   </filter>
   
-  <filter kubernetes.var.log.containers.eventrouter-** kubernetes.var.log.containers.cluster-logging-eventrouter-**>
+  <filter kubernetes.var.log.pods.**_eventrouter-**>
     @type parse_json_field
     merge_json_log true
     preserve_json_log true
@@ -510,19 +512,19 @@ var _ = Describe("Testing Complete Config Generation", func() {
       remove_keys 'log,stream,MESSAGE,_SOURCE_REALTIME_TIMESTAMP,__REALTIME_TIMESTAMP,CONTAINER_ID,CONTAINER_ID_FULL,CONTAINER_NAME,PRIORITY,_BOOT_ID,_CAP_EFFECTIVE,_CMDLINE,_COMM,_EXE,_GID,_HOSTNAME,_MACHINE_ID,_PID,_SELINUX_CONTEXT,_SYSTEMD_CGROUP,_SYSTEMD_SLICE,_SYSTEMD_UNIT,_TRANSPORT,_UID,_AUDIT_LOGINUID,_AUDIT_SESSION,_SYSTEMD_OWNER_UID,_SYSTEMD_SESSION,_SYSTEMD_USER_UNIT,CODE_FILE,CODE_FUNCTION,CODE_LINE,ERRNO,MESSAGE_ID,RESULT,UNIT,_KERNEL_DEVICE,_KERNEL_SUBSYSTEM,_UDEV_SYSNAME,_UDEV_DEVNODE,_UDEV_DEVLINK,SYSLOG_FACILITY,SYSLOG_IDENTIFIER,SYSLOG_PID'
     </formatter>
     <formatter>
-      tag "kubernetes.var.log.containers.eventrouter-** kubernetes.var.log.containers.cluster-logging-eventrouter-** k8s-audit.log** openshift-audit.log** ovn-audit.log**"
+      tag "kubernetes.var.log.pods.**_eventrouter-** k8s-audit.log** openshift-audit.log** ovn-audit.log**"
       type k8s_json_file
       remove_keys log,stream,CONTAINER_ID_FULL,CONTAINER_NAME
       process_kubernetes_events 'true'
     </formatter>
     <formatter>
-      tag "kubernetes.var.log.containers**"
+      tag "kubernetes.var.log.pods**"
       type k8s_json_file
       remove_keys log,stream,CONTAINER_ID_FULL,CONTAINER_NAME
     </formatter>
     <elasticsearch_index_name>
       enabled 'true'
-      tag "journal.system** system.var.log** **_default_** **_kube-*_** **_openshift-*_** **_openshift_**"
+      tag "kubernetes.var.log.pods.openshift-*_** kubernetes.var.log.pods.default_** kubernetes.var.log.pods.kube-*_** journal.system** system.var.log**"
       name_type static
       static_index_name infra-write
     </elasticsearch_index_name>
@@ -545,11 +547,11 @@ var _ = Describe("Testing Complete Config Generation", func() {
     @type elasticsearch_genid_ext
     hash_id_key viaq_msg_id
     alt_key kubernetes.event.metadata.uid
-    alt_tags 'kubernetes.var.log.containers.logging-eventrouter-*.** kubernetes.var.log.containers.eventrouter-*.** kubernetes.var.log.containers.cluster-logging-eventrouter-*.** kubernetes.journal.container._default_.kubernetes-event'
+    alt_tags 'kubernetes.var.log.pods.**_eventrouter-*.** kubernetes.journal.container._default_.kubernetes-event'
   </filter>
   
   # Include Infrastructure logs
-  <match **_default_** **_kube-*_** **_openshift-*_** **_openshift_** journal.** system.var.log**>
+  <match kubernetes.var.log.pods.openshift-*_** kubernetes.var.log.pods.default_** kubernetes.var.log.pods.kube-*_** journal.** system.var.log**>
     @type relabel
     @label @_INFRASTRUCTURE
   </match>
