@@ -13,7 +13,7 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
-var _ = Describe("[Functional][LogForwarding] InputSelector filtering", func() {
+var _ = Describe("[Functional][Collection] InputSelector filtering", func() {
 	_, filename, _, _ := runtime.Caller(0)
 	log.Info("Running ", "filename", filename)
 
@@ -22,7 +22,7 @@ var _ = Describe("[Functional][LogForwarding] InputSelector filtering", func() {
 	)
 
 	var (
-		instance *functional.FluentdFunctionalFramework
+		instance *functional.CollectorFunctionalFramework
 	)
 	//appNamespace2 := "application-ns2"
 	appLabels1 := map[string]string{"name": "app1", "env": "env1"}
@@ -36,7 +36,7 @@ var _ = Describe("[Functional][LogForwarding] InputSelector filtering", func() {
 		Describe("from pods identified by labels", func() {
 
 			It("should send logs from specific applications by using labels", func() {
-				instance = functional.NewFluentdFunctionalFramework()
+				instance = functional.NewCollectorFunctionalFramework()
 				instance.Labels = map[string]string{
 					"name":     "app1",
 					"env":      "env1",
@@ -96,7 +96,7 @@ var _ = Describe("[Functional][LogForwarding] InputSelector filtering", func() {
 		Describe("from pods identified by labels and namespaces", func() {
 			It("should send logs with labels name:app1 and env:env1 from namespace application-ns1 to fluentd only", func() {
 
-				instance = functional.NewFluentdFunctionalFramework()
+				instance = functional.NewCollectorFunctionalFramework()
 				instance.Labels = map[string]string{
 					"name": "app1",
 					"env":  "env1",
@@ -118,7 +118,7 @@ var _ = Describe("[Functional][LogForwarding] InputSelector filtering", func() {
 				Expect(instance.WritesApplicationLogs(1)).To(Succeed(), "Expected no errors writing log messages")
 
 				msg := functional.NewCRIOLogMessage(functional.CRIOTime(time.Now()), "Here is my message", false)
-				filepath := fmt.Sprintf("/var/log/containers/%s_%s_%s-%s.log", "myname", "application1", "thecontainer", "12345")
+				filepath := fmt.Sprintf("/var/log/pods/%s_%s_%s/%s/0.log", "myname", "application1", "12345", "thecontainer")
 				Expect(instance.WriteMessagesToLog(msg, 1, filepath)).To(Succeed(), "Expected no errors writing log messages")
 
 				logs, err := instance.ReadApplicationLogsFrom(logging.OutputTypeFluentdForward)
